const fs = require('fs');
const path = require('path');
const os = require('os');
const crypto = require('crypto');

// Uygulamanın verilerini saklayacağı dizini bulma
function getAppDataPath() {
  if (os.platform() === 'win32') {
    return path.join(process.env.APPDATA, 'seyfooksck');  // Windows
  } else if (os.platform() === 'linux' || os.platform() === 'darwin') {
    return path.join(os.homedir(), '.seyfooksck');  // Linux / macOS
  } else {
    throw new Error('Unsupported platform');
  }
}

// Anahtar oluşturma (rastgele bir key üretir)
function generateKey() {
  return crypto.randomBytes(16).toString('hex');  // 32 karakterlik hexadecimal anahtar
}

// Anahtarı dosyadan okuma veya oluşturma
function readKey() {
  const appDataPath = getAppDataPath();
  const keyFilePath = path.join(appDataPath, 'skeyid.json');

  if (!fs.existsSync(appDataPath)) {
    fs.mkdirSync(appDataPath, { recursive: true });  // Eğer dizin yoksa oluştur
  }

  if (!fs.existsSync(keyFilePath)) {
    // Anahtar dosyası yoksa, yeni bir anahtar oluştur
    const key = generateKey();
    fs.writeFileSync(keyFilePath, JSON.stringify({ key }));
    return key;
  }

  // Anahtar dosyasını oku
  const data = JSON.parse(fs.readFileSync(keyFilePath, 'utf8'));
  return data.key;
}

// Anahtarı sıfırlama (yeni bir anahtar oluşturma)
function resetKey() {
  const appDataPath = getAppDataPath();
  const keyFilePath = path.join(appDataPath, 'skeyid.json');

  const newKey = generateKey();
  fs.writeFileSync(keyFilePath, JSON.stringify({ key: newKey }));
  return newKey;
}

// `skeyid()` fonksiyonu
function skeyid(command = '') {
  if (command === 'reset') {
    return resetKey();
  } else {
    return readKey();
  }
}

module.exports = { skeyid };
